#ifndef SM_DEVCTL_H__
#define SM_DEVCTL_H__

#define NUM_MAX 128

struct devctl_netcards {
    char netcards[NUM_MAX];
};

//接口类型枚举
enum interface_type {
    INF_SERIAL = 1,
    INF_PARALLEL,
    INF_1394,
    INF_PCMCIA,
    INF_MAX
};

//设备类型枚举
enum device_type    {
    DEV_BLUETOOTH = 1,
    DEV_INFRARED,
    DEV_MODEM,
    DEV_STORAGE_DRIVE,
    DEV_SCSI_RAID,
    DEV_WINCE,
    DEV_FLOPPY_DRIVE,
    DEV_IMAGE,
    DEV_MULTI_SERIAL_CARD,
    DEV_NET_CARD,
    DEV_PRINTER,
    DEV_CDROM,
    DEV_MAX
};

enum usb_subtype    {
    USB_CLASS_PER_INTERFACE = 1,
    USB_CLASS_AUDIO,
    USB_CLASS_COMM,
    USB_CLASS_HID,
    USB_CLASS_PHYSICAL,
    USB_CLASS_STILL_IMAGE,
    USB_CLASS_PRINTER,
    USB_CLASS_MASS_STORAGE,
    USB_CLASS_HUB,
    USB_CLASS_CDC_DATA,
    USB_CLASS_CSCID,
    USB_CLASS_CONTENT_SEC,
    USB_CLASS_VIDEO,
    USB_CLASS_WIRELESS_CONTROLLER,
    USB_CLASS_MISC,
    USB_CLASS_APP_SPEC,
    USB_CLASS_VENDOR_SPEC,
    USB_CLASS_PERSONAL_HEALTH,
    USB_CLASS_DIAGNOSTIC,
    USB_MAX
};

enum dectl_perm{
    DEVCTL_ENABLE = 1,          //启用
    DEVCTL_DISABLE = 2,         //禁用
    DEVCTL_RO = 5            //只读
};

struct devctl_policy_info {
    int inf_type;			//见上面的接口枚举
    int dev_type;		    //见上面的设备枚举
    int usb_type;           //见上面的usb设备枚举
    int perm;				// 设备(接口)权限
};

struct devctl_special_device_policy {
    int usb_class;       //指定设备的类型
    unsigned int pid;      //指定设备的pid
    unsigned int vid;      //指定设备的vid
    int perm;             //指定设备的权限
};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 添加接口的管控策略
 * 
 * @param recv 接口管控策略
 * @return 0 成功， 
 *         -1 认证失败
 *         -2 非法参数
 *         其他 添加失败
 */
int devctl_add_inf_policy(struct devctl_policy_info * recv);

/**
 * @brief 删除接口的管控策略
 * 
 * @param recv 接口管控策略
 * @return 0 成功， 
 *         -1 认证失败
 *         -2 非法参数
 *         其他 删除失败
 */
int devctl_remove_inf_policy(struct devctl_policy_info *recv);

/**
 * @brief 添加设备的管控策略
 * 
 * @param recv 设备管控策略
 * @return 0 成功， 
 *         -1 认证失败
 *         -2 非法参数
 *         其他 添加失败 
 */
int devctl_add_device_policy(struct devctl_policy_info * recv);

/**
 * @brief 删除设备的管控策略
 * 
 * @param recv 设备管控策略
 * @return 0 成功， 
 *         -1 认证失败
 *         -2 非法参数
 *         其他 删除失败 
 */
int devctl_remove_device_policy(struct devctl_policy_info *recv);

/**
 * @brief 添加usb设备的管控策略
 * 
 * @param recv usb设备管控策略
 * @return 0 成功， 
 *         -1 认证失败
 *         -2 非法参数
 *         其他 添加失败
 */
int devctl_add_usb_policy(struct devctl_policy_info * recv);

/**
 * @brief 删除usb设备的管控策略
 * 
 * @param recv usb设备管控策略
 * @return 0 成功， 
 *         -1 认证失败
 *         -2 非法参数
 *         其他 删除失败
 */
int devctl_remove_usb_policy(struct devctl_policy_info *recv);

/**
 * @brief 添加指定设备的管控策略
 * 
 * @param recv usb设备管控策略
 * @return 0 成功，
 *         -1 认证失败
 *         -2 非法参数
 *         其他 删除失败
 */
int devctl_add_special_device_policy(struct devctl_special_device_policy * recv);

/**
 * @brief 删除指定设备的管控策略
 * 
 * @param recv usb设备管控策略
 * @return 0 成功， 
 *         -1 认证失败
 *         -2 非法参数
 *         其他 删除失败
 */
int devctl_remove_special_device_policy(struct devctl_special_device_policy *recv);

/**
 * @brief 获取当前外设管控所有的管控策略
 * 
 * @param count 策略数量，传出
 * @return struct devctl_policy_info* 策略数组， Null，失败  非Null，成功
 */
struct devctl_policy_info * devctl_get_all_policies(int *count);

/**
 * @brief 获取接口的管控策略
 * 
 * @param count 策略数量，传出
 * @return struct devctl_policy_info* 策略数组， Null，失败  非Null，成功
 */
struct devctl_policy_info * devctl_get_inf_policies(int *count);

/**
 * @brief 获取设备的管控策略
 * 
 * @param count 策略数量，传出
 * @return struct devctl_policy_info* 策略数组， Null，失败  非Null，成功
 */
struct devctl_policy_info *devctl_get_device_policies(int *count);

/**
 * @brief 获取usb设备的管控策略
 * 
 * @param count 策略数量，传出
 * @return struct devctl_policy_info* 策略数组， Null，失败  非Null，成功
 */
struct devctl_policy_info *devctl_get_usb_device_policies(int *count);

/**
 * @brief 获取所有指定设备的管控策略
 * 
 * @param count 策略数量，传出
 * @return struct devctl_special_device_policy* 策略数组， Null，失败  非Null，成功
 */
struct devctl_special_device_policy *devctl_get_special_device_policies(int *count);


/**
 * @brief 添加网卡到黑名单，禁用该网卡
 * 
 * @param (const char) *netcards_name 网卡名称
 * @return 0 成功， 
 *         -1 参数传入异常
 *          -2 黑名单中已存在
 */
int devctl_sm_netcard_add(const char * netcard_name);


/**
 * @brief 删除黑名单中的网卡，启用该网卡
 * 
 * @param (const char) *netcards_name 网卡名称
 * @return 0 成功， 
 *         -1 参数传入异常
 *          -2 黑名单中不存在
 */
int devctl_sm_netcard_del(const char * netcard_name);


/**
 * @brief 获取禁用黑名单中的网卡
 * 
 * @param (int) *count 网卡的个数
 * @return *
 */
struct devctl_netcards * devctl_get_all_netcard_blacklist(int *count);

#ifdef __cplusplus
}
#endif

#endif
